---
name: Report a compatibility issue
about: This package doesn't work on my OS or hardware
title: ''
labels: bug
assignees: ''

---

**What is the result of running `python -m battery`**?
_Please paste the JSON result (or any error messages!)._
_If anything is unexpected (eg `active` is True when you're plugged in) please note it._

**What OS are you running?**
_Please include the distro and version!_

**What hardware are you running?**
_A model name may be helpful, as sometimes the battery drivers are behind compatibility issues._
